@@ -13,7 +13,9 @@ mod2 <- lm(mpg ~ factor(gear), mtcars)
 expect_snapshot_print(summary(mod1), "print-lm_summary")
 
 # Always fails
-expect_false(ignore(expect_snapshot_print)(summary(mod2), "print-lm_summary"))
+if (!SKIP) {
+  expect_false(ignore(expect_snapshot_print)(summary(mod2), "print-lm_summary"))
+}
 
 
 # Use fn_*() to remove random string from snapshot
@@ -21,8 +23,9 @@ expect_false(ignore(expect_snapshot_print)(summary(mod2), "print-lm_summary"))
 set.seed(NULL)
 x <- paste0("blah_", sample(1:1e6, 1))
 fn <- function(x) sub("_.*", "", x)
-expect_snapshot_print(x,
-    label = "print-sub_label_fn",
-    fn_current = fn,
-    fn_target = fn)
-
+expect_snapshot_print(
+  x,
+  label = "print-sub_label_fn",
+  fn_current = fn,
+  fn_target = fn
+)
